pub struct ProtocolVersion(/* private fields */);Expand description
Represents the MCP protocol version used for communication.
This ensures compatibility between clients and servers by specifying which version of the Model Context Protocol is being used.
Implementations
Sourceimpl ProtocolVersion
impl ProtocolVersion
pub const V_2025_06_18: ProtocolVersion
pub const V_2025_03_26: ProtocolVersion
pub const V_2024_11_05: ProtocolVersion
pub const LATEST: ProtocolVersion = Self::V_2025_06_18
Sourcepub const KNOWN_VERSIONS: &'static [ProtocolVersion]
pub const KNOWN_VERSIONS: &'static [ProtocolVersion]
All protocol versions known to this SDK.